import { Markdown } from './Markdown';
import { OpenAPIDisclosureGroup } from './OpenAPIDisclosureGroup';
import { OpenAPIResponse } from './OpenAPIResponse';
import { StaticSection } from './StaticSection';
/**
 * Display an interactive response body.
 */
export function OpenAPIResponses(props) {
    var responses = props.responses, context = props.context;
    return (<StaticSection header="Responses" className="openapi-responses">
            <OpenAPIDisclosureGroup allowsMultipleExpanded icon={context.icons.chevronRight} groups={Object.entries(responses).map(function (_a) {
            var statusCode = _a[0], response = _a[1];
            var tabs = (function () {
                var _a;
                // If there is no content, but there are headers, we need to show the headers
                if ((!response.content || !Object.keys(response.content).length) &&
                    response.headers &&
                    Object.keys(response.headers).length) {
                    return [
                        {
                            id: 'default',
                            body: (<OpenAPIResponse response={response} mediaType={{}} context={context}/>),
                        },
                    ];
                }
                return Object.entries((_a = response.content) !== null && _a !== void 0 ? _a : {}).map(function (_a) {
                    var contentType = _a[0], mediaType = _a[1];
                    return ({
                        id: contentType,
                        label: contentType,
                        body: (<OpenAPIResponse response={response} mediaType={mediaType} context={context}/>),
                    });
                });
            })();
            var description = response.description;
            return {
                id: statusCode,
                label: (<div className="openapi-response-tab-content">
                                    <span className="openapi-response-statuscode">
                                        {statusCode}
                                    </span>
                                    {description ? (<Markdown source={description} className="openapi-response-description"/>) : null}
                                </div>),
                tabs: tabs,
            };
        })}/>
        </StaticSection>);
}
